@@ -3,6 +3,10 @@ import os.path
 # from appserver import Application
 from paxd.server.controller import Controller
 
-if __name__ == '__main__':
+def main():
     c = Controller('3489y3ngyqr87gy32r8fnyehwiufhe98')
     c.run()
+
+
+if __name__ == '__main__':
+    main()
\ No newline at end of file
